OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Tasks" : "Tasques",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Heu creat el calendari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha suprimit el calendari {calendar}",
    "You deleted calendar {calendar}" : "Heu suprimit el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Heu actualitzat el calendari {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} ha restaurat el calendari {calendar}",
    "You restored calendar {calendar}" : "Heu restaurat el calendari {calendar}",
    "You shared calendar {calendar} as public link" : "Heu compartit el calendari {calendar} amb un enllaç públic",
    "You removed public link for calendar {calendar}" : "Heu suprimit l'enllaç públic del calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vós",
    "You shared calendar {calendar} with {user}" : "Heu compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha deixat de compartir el calendari {calendar} amb vós",
    "You unshared calendar {calendar} from {user}" : "Heu deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha deixat de compartir el calendari {calendar} amb si mateix",
    "You shared calendar {calendar} with group {group}" : "Heu compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Heu deixat de compartir el calendari {calendar} amb el grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha deixat de compartir el calendari {calendar} amb el grup {grup}",
    "Untitled event" : "Esdeveniment sense títol",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha suprimit l'esdeveniment {esdeveniment} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Heu suprimit l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha actualitzat l'esdeveniment {esdeveniment} del calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} del calendari {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} ha desplaçat l'esdeveniment {event} del calendari {sourceCalendar} al calendari {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Heu desplaçat l'esdeveniment {event} del calendari {sourceCalendar} al calendari {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ha restaurat l'esdeveniment {event} del calendari {calendar}",
    "You restored event {event} of calendar {calendar}" : "Heu restaurat l'esdeveniment {event} del calendari {calendar}",
    "Busy" : "Ocupat",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} ha creat la tasca pendent {todo} en la llista {calendar}",
    "You created to-do {todo} in list {calendar}" : "Heu creat la tasca pendent {todo} en la llista {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} ha suprimit la tasca pendent {todo} de la llista {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Heu suprimit la tasca pendent {todo} de la llista {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} ha actualitzat la tasca pendent {todo} de la llista {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Heu actualitzat la tasca pendent {todo} de la llista {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} ha resolt la tasca pendent {todo} de la llista {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Heu resolt la tasca pendent {todo} de la llista {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} ha tornat a obrir la tasca pendent {todo} de la llista {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Heu tornat a obrir la tasca pendent {todo} de la llista {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} ha desplaçat la tasca pendent {todo} de la llista {sourceCalendar} a la llista {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Heu desplaçat la tasca pendent {todo} de la llista {sourceCalendar} a la llista {targetCalendar}",
    "Calendar, contacts and tasks" : "Calendari, contactes i tasques",
    "A <strong>calendar</strong> was modified" : "S'ha modificat un <strong>calendari</strong>",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong>esdeveniment</strong> del calendari",
    "A calendar <strong>to-do</strong> was modified" : "S'ha modificat una <strong>tasca pendent</strong> del calendari",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Death of %s" : "Mort de %s",
    "Untitled calendar" : "Calendari sense títol",
    "Calendar:" : "Calendari:",
    "Date:" : "Data:",
    "Where:" : "Ubicació:",
    "Description:" : "Descripció:",
    "_%n year_::_%n years_" : ["%n any","%n anys"],
    "_%n month_::_%n months_" : ["%n mes","%n mesos"],
    "_%n day_::_%n days_" : ["%n dia","%n dies"],
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuts"],
    "%s (in %s)" : "%s (d'aquí a %s)",
    "%s (%s ago)" : "%s (fa %s)",
    "Calendar: %s" : "Calendari: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descripció: %s",
    "Where: %s" : "Ubicació: %s",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Cancelled: %1$s" : "S'ha cancel·lat: %1$s",
    "\"%1$s\" has been canceled" : "S'ha cancel·lat «%1$s»",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s ha acceptat la vostra invitació",
    "%1$s has tentatively accepted your invitation" : "%1$s ha acceptat provisionalment la vostra invitació",
    "%1$s has declined your invitation" : "%1$s ha rebutjat la vostra invitació",
    "%1$s has responded to your invitation" : "%1$s ha respost a la vostra invitació",
    "Invitation updated: %1$s" : "S'ha actualitzat la invitació: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s ha actualitzat l'esdeveniment «%2$s»",
    "Invitation: %1$s" : "Invitació: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vol convidar-vos a «%2$s»",
    "Organizer:" : "Organització:",
    "Attendees:" : "Assistents:",
    "Title:" : "Títol:",
    "Time:" : "Hora:",
    "Location:" : "Ubicació:",
    "Link:" : "Enllaç:",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "More options …" : "Més opcions…",
    "More options at %s" : "Més opcions a %s",
    "Contacts" : "Contactes",
    "{actor} created address book {addressbook}" : "{actor} ha creat la llibreta d'adreces {addressbook}",
    "You created address book {addressbook}" : "Heu creat la llibreta d'adreces {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} ha suprimit la llibreta d'adreces {addressbook}",
    "You deleted address book {addressbook}" : "Heu suprimit la llibreta d'adreces {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} ha actualitzat la llibreta d'adreces {addressbook}",
    "You updated address book {addressbook}" : "Heu actualitzat la llibreta d'adreces {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb vós",
    "You shared address book {addressbook} with {user}" : "Heu compartit la llibreta d'adreces {addressbook} amb {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb vós",
    "You unshared address book {addressbook} from {user}" : "Heu deixat de compartir la llibreta d'adreces {addressbook} de {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb si mateix",
    "You shared address book {addressbook} with group {group}" : "Heu compartit la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} ha compartit la llibreta d'adreces {addressbook} amb el grup {group}",
    "You unshared address book {addressbook} from group {group}" : "Heu deixat de compartir la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha deixat de compartir la llibreta d'adreces {addressbook} amb el grup {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creat el contacte {card} en la llibreta d'adreces {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Heu creat el contacte {card} en la llibreta d'adreces {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha suprimit el contacte {card} de la llibreta d'adreces {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Heu suprimit el contacte {card} de la llibreta d'adreces {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha actualitzat el contacte {card} de la llibreta d'adreces {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Heu actualitzat el contacte {card} de la llibreta d'adreces {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "S'ha modificat un <strong>contacte</strong> o una <strong>llibreta d'adreces</strong>",
    "Accounts" : "Comptes",
    "System address book which holds all accounts" : "Llibreta d'adreces del sistema que conté tots els comptes",
    "File is not updatable: %1$s" : "El fitxer no es pot actualitzar: %1$s",
    "Could not write to final file, canceled by hook" : "No s'ha pogut escriure el fitxer final perquè el ganxo ho ha cancel·lat",
    "Could not write file contents" : "No s'ha pogut escriure el contingut del fitxer",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "S'ha produït un error en copiar el fitxer a la ubicació de destinació (dades copiades: %1$s, mida esperada del fitxer: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "S'esperava una mida de fitxer de %1$s, però s'han llegit (des del client del Nextcloud) i s'han escrit (a l'emmagatzematge del Nextcloud) %2$s. Pot ser un problema de xarxa del costat d'enviament o un problema d'escriptura a l'emmagatzematge del costat del servidor.",
    "Could not rename part file to final file, canceled by hook" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final perquè el ganxo ho ha cancel·lat",
    "Could not rename part file to final file" : "No s'ha pogut canviar el nom del fitxer de part al fitxer final",
    "Failed to check file size: %1$s" : "No s'ha pogut comprovar la mida del fitxer: %1$s",
    "Could not open file" : "No s'ha pogut obrir el fitxer",
    "Encryption not ready: %1$s" : "El xifratge no està preparat: %1$s",
    "Failed to open file: %1$s" : "No s'ha pogut obrir el fitxer: %1$s",
    "Failed to unlink: %1$s" : "No s'ha pogut desenllaçar: %1$s",
    "Invalid chunk name" : "El nom del fragment no és vàlid",
    "Could not rename part file assembled from chunks" : "No s'ha pogut canviar el nom del fitxer de part muntat a partir de fragments",
    "Failed to write file contents: %1$s" : "No s'ha pogut escriure el contingut del fitxer: %1$s",
    "File not found: %1$s" : "No s'ha trobat el fitxer: %1$s",
    "System is in maintenance mode." : "El sistema és en mode de manteniment.",
    "Upgrade needed" : "Cal actualitzar",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Cal que configureu el %s perquè utilitzi HTTPS per a poder utilitzar CalDAV i CardDAV amb l'iOS/macOS.",
    "Configures a CalDAV account" : "Configura un compte CalDAV",
    "Configures a CardDAV account" : "Configura un compte CardDAV",
    "Events" : "Esdeveniments",
    "Untitled task" : "Tasca sense títol",
    "Completed on %s" : "Completada el %s",
    "Due on %s by %s" : "Venç el %s a les %s",
    "Due on %s" : "Venç el %s",
    "DAV system address book" : "Llibreta d'adreces del sistema DAV",
    "No outstanding DAV system address book sync." : "No hi ha cap sincronització pendent de la llibreta d'adreces del sistema DAV",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronització de la llibreta d'adreces del sistema DAV encara no s'ha executat perquè la instància té més de 1000 usuaris o a causa d'un error. Executeu-la manualment amb «occ dav:sync-system-addressbook».",
    "Migrated calendar (%1$s)" : "Calendari migrat (%1$s)",
    "Calendars including events, details and attendees" : "Calendaris amb esdeveniments, detalls i assistents",
    "Contacts and groups" : "Contactes i grups",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Extrem WebDAV",
    "First day" : "Primer dia",
    "Last day (inclusive)" : "Darrer dia (inclòs)",
    "Short absence status" : "Estat d'absència breu",
    "Long absence Message" : "Missatge d'absència llarga",
    "Save" : "Desa",
    "Disable absence" : "Inhabilita l'absència",
    "Absence saved" : "S'ha desat l'absència",
    "Failed to save your absence settings" : "No s'han pogut desar els paràmetres de l'absència",
    "Absence cleared" : "S'ha esborrat l'absència",
    "Failed to clear your absence settings" : "No s'han pogut esborrar els paràmetres de l'absència",
    "Time zone:" : "Fus horari:",
    "to" : "a",
    "Delete slot" : "Suprimeix la franja",
    "No working hours set" : "No s'ha definit cap horari laboral",
    "Add slot" : "Afegeix una franja",
    "Weekdays" : "Dies de la setmana",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sunday" : "Diumenge",
    "Pick a start time for {dayName}" : "Trieu una hora d'inici per a {dayName}",
    "Pick a end time for {dayName}" : "Trieu una hora de finalització per a {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Estableix automàticament l'estat de l'usuari com a «No molesteu» fora de la disponibilitat per a silenciar totes les notificacions",
    "Failed to load availability" : "No s'ha pogut carregar la disponibilitat",
    "Saved availability" : "S'ha desat la disponibilitat",
    "Failed to save availability" : "No s'ha pogut desar la disponibilitat",
    "Availability" : "Disponibilitat",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta de persones veuran quan sou fora de l'oficina quan planifiquin una reunió.",
    "Absence" : "Absència",
    "Configure your next absence period." : "Configureu el pròxim període d'absència.",
    "Calendar server" : "Servidor de calendari",
    "Send invitations to attendees" : "Envia invitacions als assistents",
    "Automatically generate a birthday calendar" : "Genera automàticament un calendari d’aniversaris",
    "Birthday calendars will be generated by a background job." : "Un procés en segon pla generarà els calendaris d'aniversaris.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per tant, no estaran disponibles immediatament després d'habilitar-los, però apareixeran després d'una estona.",
    "Send notifications for events" : "Envia notificacions per als esdeveniments",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notificacions les envien feines en segon pla, de manera que han d'ocórrer prou sovint.",
    "Send reminder notifications to calendar sharees as well" : "Envia també notificacions de recordatori als usuaris amb qui s'ha compartit el calendari",
    "Reminders are always sent to organizers and attendees." : "Sempre s'envien recordatoris als organitzadors i als assistents.",
    "Enable notifications for events via push" : "Habilita les notificacions automàtiques per als esdeveniments",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal·leu també {calendarappstoreopen}l'aplicació Calendari{linkclose} o {calendardocopen}connecteu el vostre dispositiu d'escriptori i el mòbil per a sincronitzar-los ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Assegureu-vos de configurar correctament el{emailopen}servidor de correu electrònic{linkclose}.",
    "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat d'assistència.",
    "Please contact the organizer directly." : "Contacteu amb l'organització directament.",
    "Are you accepting the invitation?" : "Accepteu la invitació?",
    "Tentative" : "Provisional",
    "Your attendance was updated successfully." : "S'ha actualitzat correctament l'assistència.",
    "To-dos" : "Tasques pendents",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta d'usuaris veuran quan sou fora de l'oficina quan planifiquin una reunió."
},
"nplurals=2; plural=(n != 1);");
